package cn.com.infosec.jce.provider.test;

import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.x509.BasicConstraints;
import cn.com.infosec.asn1.x509.CRLNumber;
import cn.com.infosec.asn1.x509.KeyUsage;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.jce.PrincipalUtil;
import cn.com.infosec.jce.X509Principal;
import cn.com.infosec.x509.X509V1CertificateGenerator;
import cn.com.infosec.x509.X509V2CRLGenerator;
import cn.com.infosec.x509.X509V3CertificateGenerator;
import cn.com.infosec.x509.extension.AuthorityKeyIdentifierStructure;
import cn.com.infosec.x509.extension.SubjectKeyIdentifierStructure;
import java.math.BigInteger;
import java.security.KeyPair;
import java.security.KeyPairGenerator;
import java.security.Principal;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.SecureRandom;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.security.cert.X509CRL;
import java.security.cert.X509Certificate;
import java.util.Date;
import java.util.Set;

class TestUtils {
   public static KeyPair generateRSAKeyPair() {
      KeyPairGenerator var10000 = KeyPairGenerator.getInstance("RSA", "INFOSEC");
      SecureRandom var0;
      var0 = new SecureRandom.<init>();
      var10000.initialize(1024, var0);
      return var10000.generateKeyPair();
   }

   public static X509Certificate generateRootCert(KeyPair pair) {
      X509V1CertificateGenerator var1;
      X509V1CertificateGenerator var10000 = var1 = new X509V1CertificateGenerator;
      var1.<init>();
      var1.setSerialNumber(BigInteger.valueOf(1L));
      var1.setIssuerDN(new X509Principal("CN=Test CA Certificate"));
      var1.setNotBefore(new Date(System.currentTimeMillis() - 50000L));
      var1.setNotAfter(new Date(System.currentTimeMillis() + 50000L));
      var1.setSubjectDN(new X509Principal("CN=Test CA Certificate"));
      var1.setPublicKey(pair.getPublic());
      var1.setSignatureAlgorithm("SHA256WithRSAEncryption");
      return var10000.generateX509Certificate(pair.getPrivate(), "INFOSEC");
   }

   public static X509Certificate generateIntermediateCert(PublicKey intKey, PrivateKey caKey, X509Certificate caCert) {
      X509V3CertificateGenerator var3;
      X509V3CertificateGenerator var10000 = var3 = new X509V3CertificateGenerator;
      PrivateKey var10001 = caKey;
      var3.<init>();
      var3.setSerialNumber(BigInteger.valueOf(1L));
      var3.setIssuerDN(PrincipalUtil.getSubjectX509Principal(caCert));
      var3.setNotBefore(new Date(System.currentTimeMillis() - 50000L));
      var3.setNotAfter(new Date(System.currentTimeMillis() + 50000L));
      var3.setSubjectDN(new X509Principal("CN=Test Intermediate Certificate"));
      var3.setPublicKey(intKey);
      var3.setSignatureAlgorithm("SHA256WithRSAEncryption");
      DERObjectIdentifier var10006 = X509Extensions.AuthorityKeyIdentifier;
      AuthorityKeyIdentifierStructure caKey1;
      caKey1 = new AuthorityKeyIdentifierStructure.<init>(caCert);
      var3.addExtension(var10006, false, caKey1);
      DERObjectIdentifier var10005 = X509Extensions.SubjectKeyIdentifier;
      SubjectKeyIdentifierStructure caKey2;
      caKey2 = new SubjectKeyIdentifierStructure.<init>(intKey);
      var3.addExtension(var10005, false, caKey2);
      DERObjectIdentifier var10004 = X509Extensions.BasicConstraints;
      BasicConstraints intKey1;
      intKey1 = new BasicConstraints.<init>(0);
      var3.addExtension(var10004, true, intKey1);
      DERObjectIdentifier var10003 = X509Extensions.KeyUsage;
      KeyUsage intKey2;
      intKey2 = new KeyUsage.<init>(134);
      var3.addExtension(var10003, true, intKey2);
      return var10000.generateX509Certificate(var10001, "INFOSEC");
   }

   public static X509Certificate generateEndEntityCert(PublicKey entityKey, PrivateKey caKey, X509Certificate caCert) {
      X509V3CertificateGenerator var3;
      X509V3CertificateGenerator var10000 = var3 = new X509V3CertificateGenerator;
      PrivateKey var10001 = caKey;
      var3.<init>();
      var3.setSerialNumber(BigInteger.valueOf(1L));
      var3.setIssuerDN(PrincipalUtil.getSubjectX509Principal(caCert));
      var3.setNotBefore(new Date(System.currentTimeMillis() - 50000L));
      var3.setNotAfter(new Date(System.currentTimeMillis() + 50000L));
      var3.setSubjectDN(new X509Principal("CN=Test End Certificate"));
      var3.setPublicKey(entityKey);
      var3.setSignatureAlgorithm("SHA256WithRSAEncryption");
      DERObjectIdentifier var10006 = X509Extensions.AuthorityKeyIdentifier;
      AuthorityKeyIdentifierStructure caKey1;
      caKey1 = new AuthorityKeyIdentifierStructure.<init>(caCert);
      var3.addExtension(var10006, false, caKey1);
      DERObjectIdentifier var10005 = X509Extensions.SubjectKeyIdentifier;
      SubjectKeyIdentifierStructure caKey2;
      caKey2 = new SubjectKeyIdentifierStructure.<init>(entityKey);
      var3.addExtension(var10005, false, caKey2);
      DERObjectIdentifier var10004 = X509Extensions.BasicConstraints;
      BasicConstraints entityKey1;
      entityKey1 = new BasicConstraints.<init>(false);
      var3.addExtension(var10004, true, entityKey1);
      DERObjectIdentifier var10003 = X509Extensions.KeyUsage;
      KeyUsage entityKey2;
      entityKey2 = new KeyUsage.<init>(160);
      var3.addExtension(var10003, true, entityKey2);
      return var10000.generateX509Certificate(var10001, "INFOSEC");
   }

   public static X509CRL createCRL(X509Certificate caCert, PrivateKey caKey, BigInteger serialNumber) {
      X509V2CRLGenerator var3;
      X509V2CRLGenerator var10000 = var3 = new X509V2CRLGenerator;
      PrivateKey var10001 = caKey;
      var3.<init>();
      Date caKey1;
      caKey1 = new Date.<init>();
      BigInteger.valueOf(2L);
      var3.setIssuerDN(PrincipalUtil.getSubjectX509Principal(caCert));
      var3.setThisUpdate(caKey1);
      var3.setNextUpdate(new Date(caKey1.getTime() + 100000L));
      var3.setSignatureAlgorithm("SHA256WithRSAEncryption");
      var3.addCRLEntry(serialNumber, caKey1, 9);
      DERObjectIdentifier var10004 = X509Extensions.AuthorityKeyIdentifier;
      AuthorityKeyIdentifierStructure caKey2;
      caKey2 = new AuthorityKeyIdentifierStructure.<init>(caCert);
      var3.addExtension(var10004, false, caKey2);
      DERObjectIdentifier var10003 = X509Extensions.CRLNumber;
      CRLNumber caCert1;
      caCert1 = new CRLNumber.<init>(BigInteger.valueOf(1L));
      var3.addExtension(var10003, false, caCert1);
      return var10000.generateX509CRL(var10001, "INFOSEC");
   }

   public static X509Certificate createExceptionCertificate(boolean exceptionOnEncode) {
      return new ExceptionCertificate(exceptionOnEncode);
   }

   private static class ExceptionCertificate extends X509Certificate {
      private boolean _exceptionOnEncode;

      public ExceptionCertificate(boolean exceptionOnEncode) {
         this._exceptionOnEncode = exceptionOnEncode;
      }

      public void checkValidity() {
         throw new CertificateNotYetValidException();
      }

      public void checkValidity(Date date) {
         throw new CertificateExpiredException();
      }

      public int getVersion() {
         return 0;
      }

      public BigInteger getSerialNumber() {
         return null;
      }

      public Principal getIssuerDN() {
         return null;
      }

      public Principal getSubjectDN() {
         return null;
      }

      public Date getNotBefore() {
         return null;
      }

      public Date getNotAfter() {
         return null;
      }

      public byte[] getTBSCertificate() {
         throw new CertificateEncodingException();
      }

      public byte[] getSignature() {
         return new byte[0];
      }

      public String getSigAlgName() {
         return null;
      }

      public String getSigAlgOID() {
         return null;
      }

      public byte[] getSigAlgParams() {
         return new byte[0];
      }

      public boolean[] getIssuerUniqueID() {
         return new boolean[0];
      }

      public boolean[] getSubjectUniqueID() {
         return new boolean[0];
      }

      public boolean[] getKeyUsage() {
         return new boolean[0];
      }

      public int getBasicConstraints() {
         return 0;
      }

      public byte[] getEncoded() {
         if (!this._exceptionOnEncode) {
            return new byte[0];
         } else {
            throw new CertificateEncodingException();
         }
      }

      public void verify(PublicKey key) {
         throw new CertificateException();
      }

      public void verify(PublicKey key, String sigProvider) {
         throw new CertificateException();
      }

      public String toString() {
         return null;
      }

      public PublicKey getPublicKey() {
         return null;
      }

      public boolean hasUnsupportedCriticalExtension() {
         return false;
      }

      public Set getCriticalExtensionOIDs() {
         return null;
      }

      public Set getNonCriticalExtensionOIDs() {
         return null;
      }

      public byte[] getExtensionValue(String oid) {
         return new byte[0];
      }
   }
}
